@@ -13,9 +13,11 @@ using namespace std;
 class GenericError : public AppError
 {
 public:
-	GenericError( char *msg );
+	GenericError( const char *msg );
 	GenericError( string msg ) { m=msg; };
 	GenericError( const GenericError &ge );
+  virtual ~GenericError() { }
+
 	string msg() const;
 private:
 	string m;
