@@ -7,19 +7,19 @@
 #elif HAVE_EXT_HASH_MAP
 #include <ext/hash_map>
 #endif
-#include "SocketPair4.h"
+#include "SocketPair.h"
 #include "util.h"
 #include "TCPConnection.h"
-#include "IPv4TCPCapture.h"
+#include "TCPCapture.h"
 
 #ifdef GNU_CXX_NS
 using namespace __gnu_cxx;
 #endif
 
-class GEqFunc : public unary_function<SocketPair4,bool>
+class GEqFunc : public unary_function<SocketPair,bool>
 {
 public:
-	bool operator()( const SocketPair4 &sp1, const SocketPair4 & sp2 )
+	bool operator()( const SocketPair &sp1, const SocketPair & sp2 )
 	{
 		if( sp1==sp2 )
 			return true;
@@ -28,27 +28,16 @@ public:
 	}
 };
 
-// TODO: banged out off the top of my head... could be improved.
-class GHashFunc : public unary_function<SocketPair4, size_t>
+class GHashFunc : public unary_function<SocketPair, uint32_t>
 {
 public:
-	size_t operator()(const SocketPair4 &sp) const
+	uint32_t operator()(const SocketPair &sp) const
 	{
-		size_t rv=0;
-		if( sp.portB() > 0 )
-			rv = sp.addrA().toStruct().s_addr % sp.portB();
-		else
-			rv = sp.addrA().toStruct().s_addr;
-		rv >> 4;
-		if( sp.portA() > 0 )
-			rv += sp.addrB().toStruct().s_addr % sp.portA();
-		else
-			rv += sp.addrB().toStruct().s_addr;
-		return rv;
+		return sp.hash();
 	}
 };
 
-typedef hash_map<SocketPair4, IPv4TCPCapture *,GHashFunc, GEqFunc> pktmap;
+typedef hash_map<SocketPair, TCPCapture *,GHashFunc, GEqFunc> pktmap;
 
 /* Guesser implements the 'detect connections that started before
  * tcptrack was started' functionality.
@@ -66,7 +55,7 @@ public:
 	// feed Guesser a stray packet. If it results in a connection
 	// detected, it will be returned. If no new connections, NULL 
 	// is returned.
-	TCPConnection * addPacket( IPv4TCPCapture &p );
+	TCPConnection * addPacket( TCPCapture &p );
 private:
 	// stray packets that we're keeping track of are stored here.
 	// indexed by src/dst addrs and ports.
