@@ -11,7 +11,7 @@ using namespace std;
 class PcapError : public AppError
 {
 public:
-	PcapError( char *func, char *errbuf );
+	PcapError( const char *func, char *errbuf );
 	PcapError( const PcapError &e );
 	string msg() const;
 private:
