@@ -39,9 +39,8 @@
 #include "TCPConnection.h"
 #include "SortedIterator.h"
 #include "util.h"
-#include "IPv4Packet.h"
-#include "IPv4TCPCapture.h"
-#include "SocketPair4.h"
+#include "TCPCapture.h"
+#include "SocketPair.h"
 
 #define TSTATE_IDLE 1
 #define TSTATE_RUNNING 2
@@ -55,10 +54,10 @@ using namespace __gnu_cxx;
 
 /////
 
-class TCCEqFunc : public unary_function<SocketPair4,bool>
+class TCCEqFunc : public unary_function<SocketPair,bool>
 {
 public:
-	bool operator()( const SocketPair4 &sp1, const SocketPair4 &sp2 ) 
+	bool operator()( const SocketPair &sp1, const SocketPair &sp2 ) 
 	{
 		if( sp1==sp2 )
 			return true;
@@ -68,26 +67,16 @@ public:
 };
 
 // TODO: banged out off the top of my head... could be improved.
-class TCCHashFunc : public unary_function<SocketPair4, size_t>
+class TCCHashFunc : public unary_function<SocketPair, uint32_t>
 {
 public:
-	size_t operator()(const SocketPair4 &sp) const
+	uint32_t operator()(const SocketPair &sp) const
 	{
-		size_t rv=0;
-		if( sp.portB() > 0 )
-			rv = sp.addrA().toStruct().s_addr % sp.portB();
-		else
-			rv = sp.addrA().toStruct().s_addr;
-		rv >> 4;
-		if( sp.portA() > 0 )
-			rv += sp.addrB().toStruct().s_addr % sp.portA();
-		else
-			rv += sp.addrB().toStruct().s_addr;
-		return rv;
+		return sp.hash();
 	}
 };
 
-typedef hash_map<SocketPair4, TCPConnection *, TCCHashFunc, TCCEqFunc> tccmap;
+typedef hash_map<SocketPair, TCPConnection *, TCCHashFunc, TCCEqFunc> tccmap;
 
 ////
 
@@ -101,7 +90,7 @@ public:
 	TCContainer();
 	~TCContainer();
 
-	bool processPacket( IPv4TCPCapture &p );
+	bool processPacket( TCPCapture &p );
 	unsigned int numConnections();
 
 	void stop();
@@ -111,7 +100,7 @@ public:
 
 	// do not call. only called from maint_thread_func.
 	void maint_thread_run();
-	
+
 	SortedIterator * getSortedIteratorPtr();
 
 	// remove closed connections?
@@ -121,7 +110,7 @@ private:
 	// delay. Right now it just deletes them. It could log their stats
 	// or something...
 	Collector collector;
-	
+
 	// this is a hash table that stores all the connections we're 
 	// currently tracking.
 	tccmap conhash2;	
@@ -139,7 +128,7 @@ private:
 	// a connection exists, it feeds it to TCContainer which keeps
 	// track of it as usual.
 	Guesser guesser;
-	
+
 	// for starting up, shutting down the maint thread.
 	int state;
 	pthread_mutex_t state_mutex;
