@@ -1,6 +1,8 @@
 #include <cassert>
 #include <pthread.h>
 #include <iostream>
+#include <cstring>
+#include <string>
 #include "TCPTrack.h"
 #include "AppError.h"
 #include "PcapError.h"
@@ -125,14 +127,12 @@ struct config parseopts(int argc, char **argv)
 {
 	int o;
 	struct config cf;
-	// TODO: this is leaked... and should be something other than 1000
-	cf.fexp = (char *) malloc( sizeof(char) * 1000 ); 
-	cf.fexp[0]='\0';
 	cf.remto=CLOSED_PURGE;
 	cf.fastmode=false;
 	cf.promisc=true;
 	cf.detect=true;
 	cf.test_file=NULL;
+	cf.iface = NULL;
 	bool got_iface=false;
 
 	while( (o=getopt(argc,argv,"dhvfi:pr:T:")) > 0 )
@@ -172,8 +172,13 @@ struct config parseopts(int argc, char **argv)
 		exit(1);
 	}
 	
-	for( int i=optind; i<argc; i++ )
-		sprintf(cf.fexp,"%s %s",cf.fexp,argv[i]);
+	std::string fexp;
+	for( int i=optind; i<argc; i++ ) {
+		fexp += " ";
+		fexp += argv[i];
+	}
 	
+	cf.fexp = strdup(fexp.c_str());
+
 	return cf;
 }
