@@ -119,11 +119,6 @@ TextUI::~TextUI()
 // main drawer thread loop
 void TextUI::displayer_run()
 {
-	// redraw the display this freqently...
-	struct timespec t;
-	t.tv_sec=0;
-	t.tv_nsec=DISPLAY_REFRESH;
-
 	// used for select(), to grab keyboard input when there is some.
 	fd_set fdset;
 	struct timeval tv;
